==> nextcloud-24.0.5.tgz: nextcloud/apps/viewer/l10n/ar.js <==
OC.L10N.register(
    "viewer",
    {
    "Simple file viewer with slideshow for media" : "مستعرض ملفات بسيط مع عارض شرائح للوسائط",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "اعرض أحدث صورك ومقاطع الفيديو الخاصة بالعطلات كما في الأفلام ، وأظهر لمحة عن أحدث رواياتك مباشرة من نكست كلاود ، واختر أفضل صورة GIF من مجموعتك بفضل المعاينة المباشرة لملفاتك المفضلة وغيرها الكثير!",
    "Your browser does not support audio." : "متصفحك لا يدعم الصوت.",
    "Your browser does not support videos." : "متصفحك لا يدعم الفيديوهات.",
    "Edit" : "تعديل",
    "Open sidebar" : "إفتح الشريط الجانبي",
    "Download" : "تنزيل",
    "Delete" : "حذف",
    "There is no plugin available to display this file type" : "لا يوجد مكون إضافي متاح لعرض هذا النوع من الملفات",
    "View" : "عرض",
    "Name" : "الاسم",
    "Save" : "Save",
    "Back" : "العودة",
    "Loading …" : "جاري التحميل …",
    "Reset" : "إعادة الضبط",
    "Cancel" : "إلغاء",
    "Continue" : "متابعة",
    "Undo" : "تراجع",
    "Redo" : "إعادة",
    "Original" : "أصلي",
    "Custom" : "مخصّص",
    "Value" : "القيمة",
    "Text" : "نص",
    "Size" : "الحجم",
    "Position" : "الموقع",
    "Name is required." : "حقل الاسم مطلوب",
    "Quality" : "الجودة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-25.0.5.tgz: nextcloud/apps/viewer/l10n/ar.js <==
OC.L10N.register(
    "viewer",
    {
    "Simple file viewer with slideshow for media" : "مستعرض ملفات بسيط مع عارض شرائح للوسائط",
    "Your browser does not support audio." : "متصفحك لا يدعم الصوت.",
    "Your browser does not support videos." : "متصفحك لا يدعم الفيديوهات.",
    "Edit" : "تعديل",
    "Open sidebar" : "إفتح الشريط الجانبي",
    "Download" : "تنزيل",
    "Delete" : "حذف",
    "There is no plugin available to display this file type" : "لا يوجد مكون إضافي متاح لعرض هذا النوع من الملفات",
    "View" : "عرض",
    "Name" : "الاسم",
    "Save" : "Save",
    "Back" : "العودة",
    "Loading …" : "جاري التحميل …",
    "Reset" : "إعادة الضبط",
    "Cancel" : "إلغاء",
    "Continue" : "متابعة",
    "Undo" : "تراجع",
    "Redo" : "إعادة",
    "Original" : "أصلي",
    "Custom" : "مخصّص",
    "Value" : "القيمة",
    "Line" : "خط",
    "Text" : "نص",
    "Size" : "الحجم",
    "Position" : "الموقع",
    "Name is required." : "حقل الاسم مطلوب",
    "Quality" : "الجودة",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "اعرض أحدث صورك ومقاطع الفيديو الخاصة بالعطلات كما في الأفلام ، وأظهر لمحة عن أحدث رواياتك مباشرة من نكست كلاود ، واختر أفضل صورة GIF من مجموعتك بفضل المعاينة المباشرة لملفاتك المفضلة وغيرها الكثير!"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
